package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.OmsFeign;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import io.swagger.models.auth.In;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-09-17 14:10
 */
@RestController
@RequestMapping("${api.version}/oms")
public class OMSController {


    @Autowired
    OmsFeign omsFeign;
    
    //********************************************omsTruckOrderController*****************************

    @ApiOperation(value = "查询所有运输订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(86)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllTruckOrder")
    public Map<String, Object> getAllTruckOrder(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer orderStatus,
                                          Integer planId,
                                          Integer orderType,
                                          Integer fuelOrder, String con) {
        return omsFeign.getAllTruckOrder(mapValue == null? new HashMap<>() : mapValue, apiId, pageNum, pageSize,
                orderStatus, planId, orderType, fuelOrder, con);
    }

    @ApiOperation(value = "不适用表头返回数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("/getAllTruckOrderReturnListMap")
    public Map<String, Object> getAllTruckOrderReturnListMap(Integer orderStatus, Integer planId, Integer orderType) {
        return omsFeign.getAllTruckOrderReturnListMap(orderStatus, planId, orderType);
    }

    @ApiOperation(value = "查询所有空闲的运力信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(85)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllCapacity")
    public Map<String, Object> getAllCapacity(@RequestBody(required = false) Map<String, Object> mapValue,
                                        Integer apiId,
                                        Integer pageNum,
                                        Integer pageSize,
                                        Integer carrierId
    ) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return omsFeign.getAllCapacity(mapValue, apiId, pageNum, pageSize, carrierId);
    }

    @ApiOperation(value = "分解运输计划后 新增订单  或者直接新增订单 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("/addPurOrder")
    public Map<String, Object> addPurOrder(@RequestBody(required = false) Map<String, Object> mapValue) {
        return omsFeign.addPurOrder(mapValue);
    }


    @ApiOperation(value = "修改分派计划")
    @PostMapping("/updateOrder")
    public Map<String, Object> updateOrder(@RequestBody Map<String, Object> map) {
        return omsFeign.updateOrder(map);
    }


    @ApiOperation(value = "派单")
    @PostMapping("/dispatchOrder")
    public Map<String, Object> dispatchOrder(@RequestBody(required = false) Map<String, Object> map) {
        return omsFeign.dispatchOrder(map);
    }


    @ApiOperation(value = "销售派单")
    @PostMapping("/dispatchOrderForSale")
    public Map<String, Object> dispatchorderForSale(@RequestBody(required = false) Map<String, Object> map) {
        return omsFeign.dispatchOrderForSale(map);
    }



    @ApiOperation(value = "逻辑删除运单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "运输计划Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/deleteOrder")
    public Map<String, Object> deleteOrder(@RequestBody(required = false) Map<String, Object> map,
                                     Integer planId) {
        return omsFeign.deleteOrder(map, planId);
    }

    @ApiOperation(value = "司机接收、拒绝接单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "运输订单Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/driverReceiveOrRefuse")
    public Map<String, Object> driverReceiveOrRefuse(@RequestBody(required = false) Map<String, Object> map) {
        return omsFeign.driverReceiveOrRefuse(map);
    }


    @ApiOperation(value="司机接单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(117)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getReceiveRefuseOrder/{orderReceiveStatus}")
    public Map<String, Object> getReceiveRefuseOrder(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               @PathVariable Integer orderReceiveStatus,
                                               Integer orderType,
                                               Integer orderStatus,
                                                     String con
    ){
        return omsFeign.getReceiveRefuseOrder(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum,
                pageSize, orderReceiveStatus, orderType, orderStatus, con);
    }


    @ApiOperation(value="司机APP端调用接口查询数据 4 已下发 5 已接收")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "capacityNumber", value = "车牌号", required = false, dataType = "String"),
    })
    @PostMapping("/sendMesToDriver")
    public Map<String, Object> sendMesToDriver(String capacityNumber, Integer orderStatus){
        return omsFeign.sendMesToDriver(capacityNumber, orderStatus);
    }

    @ApiOperation(value="通过车牌获取所有已拒绝的订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "capacityNumber", value = "车牌号", required = false, dataType = "String"),
    })
    @PostMapping("/getRefuseOrderByCapacityNum")
    public Map<String, Object> sendMesToDriver(String capacityNumber){
        return omsFeign.sendMesToDriver(capacityNumber);
    }

    @ApiOperation(value="通过运输订单ID查询运单信息 包含各个作业路径")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "订单Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/getOrderMesByOrderNum/{orderId}")
    public Map<String, Object> getOrderMesByOrderNum(@PathVariable("orderId") Integer orderId){
        return omsFeign.getOrderMesByOrderNum(orderId);
    }

    @ApiOperation(value="通过运输订单ID查询实绩地点和时间")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "运输订单Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectPlaceAndTime/{orderId}")
    public Map<String, Object> selectPlaceAndTime(@PathVariable("orderId") Integer orderId){
        return omsFeign.selectPlaceAndTime(orderId);
    }

    @ApiOperation(value="通过运输订单ID查询运单信息")
    @PostMapping("/selectOrderByOrderId/{orderId}")
    public Map<String, Object> selectOrderByOrderId(@PathVariable("orderId") Integer orderId){
        return omsFeign.selectOrderByOrderId(orderId);
    }

    @ApiOperation(value="查看运输派单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(117)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getTransportDispatch")
    public Map<String, Object> getTransportDispatch(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer orderType,
                                              Integer orderStatus, Integer fuelOrder,String con){
        return omsFeign.getTransportDispatch(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize,
                 orderType, orderStatus, fuelOrder, con);
    }

    /**
     * 展示承运商接收销售公司已接受的销售订单
     *
     * @param
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("/getSaleOrderForCarrierList/{carrierId}")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "168", required = false, dataType = "BigDecimal"),
    })
    public Map<String, Object> getSaleOrderForCarrierList(@RequestBody(required = false)Map<String,Object> map,
                                                          @PathVariable("carrierId") Integer carrierId,
                                                          Integer apiId,
                                                          Integer pageNum,
                                                          Integer pageSize,
                                                          String con
                                                          ) {
        return omsFeign.getSaleOrderForCarrierList(map==null ? new HashMap<>():map,carrierId, apiId, pageNum, pageSize,con);

    }

    /**
     * 展示承运商接收销售公司已接受的销售订单
     *
     * @param
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("/selectAllOrderForSale/{carrierId}")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "168", required = false, dataType = "BigDecimal"),
    })
    public Map<String, Object> selectAllOrderForSale( @RequestBody(required = false) Map<String,Object> mapValue,
                                                      @PathVariable Integer carrierId,
                                                      Integer apiId,
                                                      Integer pageNum,
                                                      Integer pageSize,
                                                      Integer orderType,
                                                      Integer orderStatus,
                                                      Integer saleOrderMaterialId,
                                                      String  con
                                                    ) {
        return omsFeign.selectAllOrderForSale(mapValue==null?new HashMap<>():mapValue, carrierId, apiId, pageNum, pageSize, orderType, orderStatus, saleOrderMaterialId, con);
    }
    /**
     * 销售物流：司机接单pc端
     */

    @ApiOperation(value="pc端展示司机信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(226)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getDriverInfoForSale")
   public Map<String,Object> getDriverInfoForSale(@RequestBody(required=false) Map<String,Object> mapValue,
                                            Integer apiId,
                                            Integer pageNum,
                                            Integer pageSize,

                                            Integer orderType,
                                            Integer orderStatus,
                                            String con,
                                            Integer carrierId
    )
    {
        return omsFeign.getDriverInfoForSale(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, orderType, orderStatus, con,carrierId);
    }



    /**
     * 查询所有已经接收的焦炭发运日计划
     *
     * @param carrierId
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @PostMapping("/getCokeDayPlanAndRecivedList/{carrierId}")

    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "169", required = false, dataType = "BigDecimal"),
    })
    public Map<String, Object> getCokeDayPlanAndRecivedList(
                                                            @RequestBody(required = false)Map<String,Object> map,
                                                            @PathVariable("carrierId") Integer carrierId,
                                                            @RequestParam Integer apiId,
                                                            @RequestParam Integer pageNum,
                                                            @RequestParam Integer pageSize) {
        return omsFeign.getCokeDayPlanAndRecivedList(map==null?new HashMap<>():map,carrierId, apiId, pageNum, pageSize);
    }

    /**
     * 查询所有已经接收的水渣发运日计划
     *
     * @param
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("/getWaterSlagDayPlanAndRecivedList/{carrierId}")

    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "170", required = false, dataType = "BigDecimal"),
    })
    public Map<String, Object> getWaterSlagDayPlanAndRecivedList(
                                                                 @RequestBody(required = false)Map<String,Object> map,
                                                                 @PathVariable("carrierId") Integer carrierId,
                                                                 @RequestParam Integer apiId,
                                                                 @RequestParam Integer pageNum,
                                                                 @RequestParam Integer pageSize) {
        return omsFeign.getWaterSlagDayPlanAndRecivedList(map==null?new HashMap<>():map, carrierId, apiId, pageNum, pageSize);
    }
    @PostMapping("/selectNewOrderId")
    public Map<String, Object> selectNewOrderId(@RequestBody(required=false) Map<String,Object> map){
        return omsFeign.selectNewOrderId(map);
    }
    @ApiOperation(value="查询所有空闲的司机排班信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(186)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getCapacityForLeisure/{carrierId}")
    public Map<String, Object> getCapacityForLeisure(@RequestBody(required = false) Map<String,Object> mapValue,
                                                     Integer apiId,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     @PathVariable Integer carrierId) {
        return omsFeign.getCapacityForLeisure(mapValue==null?new HashMap<>(): mapValue, apiId, pageNum, pageSize,carrierId);
    }
     //获取已经形成订单的焦炭计划
    @PostMapping(value = "/getCokeRailDayPlanForGenOrder/{carrierId}")
    public Map<String,Object>  getCokeRailDayPlanForGenOrder(@RequestBody(required = false)Map<String,Object> map,
                                                           @PathVariable("carrierId") Integer carrierId,
                                                           Integer pageNum,
                                                           Integer pageSize,
                                                           Integer apiId,
                                                           Integer dayPlanId,
                                                           Integer orderStatus,
                                                           Integer orderType,
                                                           String con
    ){
        return  omsFeign.getCokeRailDayPlanForGenOrder(map==null?new HashMap<>():map, carrierId, pageNum, pageSize, apiId, dayPlanId, orderStatus, orderType, con);
    }


   //获取已经形成订单的水渣计划
   @PostMapping(value = "/getWaterslagDayPlanForGenOrder/{carrierId}")
   public Map<String, Object>     getWaterslagDayPlanForGenOrder(@RequestBody(required = false)Map<String,Object> map,
                                                                 @PathVariable("carrierId") Integer carrierId,
                                                                 Integer pageNum,
                                                                 Integer pageSize,
                                                                 Integer apiId,
                                                                 Integer dayPlanId,
                                                                 Integer orderStatus,
                                                                 Integer orderType,
                                                                 String con


   ){
        return omsFeign.getWaterslagDayPlanForGenOrder(map==null?new HashMap<>():map, carrierId, pageNum, pageSize, apiId, dayPlanId, orderStatus,orderType, con);

   }

    @ApiOperation(value="车牌号下拉")
    @GetMapping("/getDriverCapacity")
    public Map<String, Object> getDriverCapacity() {
        Map<String,Object> map = omsFeign.getDriverCapacity();
        return map;
    }

    @ApiOperation(value="派单信息")
    @PostMapping("/getTruckNoDispatchMap")
    public Map<String, Object> getTruckNoDispatchMap(Integer dispatchId) {
        Map<String,Object> map = omsFeign.getTruckNoDispatchMap(dispatchId);
        return map;
    }

    @ApiOperation(value="承运商分派运输订单给司机")
    @PostMapping("/addAppTruckOrder")
    public Map<String, Object> addAppTruckOrder(Integer dispatchId,
                                                Integer orderType,
                                                String capacityNumber,
                                                Integer carrierId) {
        Map<String, Object> map = omsFeign.addAppTruckOrder(dispatchId, orderType,capacityNumber, carrierId);
        return map;
    }
    //展示销售订单信息
    @ApiOperation(value="展示销售订单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId()", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectSteelSaleForCarrier/{carrierId}")
    public Map<String, Object> selectSteelSaleForCarrier(@RequestBody(required=false) Map<String,Object> mapValue,
                                                         Integer apiId,
                                                         Integer pageNum,
                                                         Integer pageSize,
                                                         @PathVariable Integer carrierId

    )

    {
        return omsFeign.selectSteelSaleForCarrier(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, carrierId);
    }



    @ApiOperation(value=" 通过销售订单id查找信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(235)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectInfoBySaleOrderId/{saleOrderId}")
    public Map<String, Object> selectInfoBySaleOrderId(@RequestBody(required=false) Map<String,Object> mapValue,
                                                       Integer apiId,
                                                       Integer pageNum,
                                                       Integer pageSize,
                                                       @PathVariable Integer saleOrderId


    ){
        return  omsFeign.selectInfoBySaleOrderId(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize,saleOrderId);
    }

    //展示发运计划信息
    @ApiOperation(value="展示发运计划信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId()", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectCokeRailPlan/{carrierId}")
    public Map<String, Object> selectCokeRailPlan(@RequestBody(required=false) Map<String,Object> mapValue,
                                                  Integer apiId,
                                                  Integer pageNum,
                                                  Integer pageSize,
                                                  @PathVariable Integer carrierId,
                                                  Integer orderType

    ){
        return  omsFeign.selectCokeRailPlan(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, carrierId, orderType);
    }

    @ApiOperation(value=" 通过发运id查找信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId()", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectInfoByDayPlanId/{dayPlanId}")
    public Map<String, Object> selectInfoByDayPlanId(@RequestBody(required=false) Map<String,Object> mapValue,
                                                     Integer apiId,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     @PathVariable  Integer dayPlanId,
                                                     Integer orderType


    ){
        return omsFeign.selectInfoByDayPlanId(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, dayPlanId, orderType);
    }

    @ApiOperation(value="根据运单id关闭订单")
    @PostMapping("/closeOmstruckOrder")
    public Map<String, Object> closeOmstruckOrder(@RequestParam Integer orderId) {
        Map<String, Object> map = omsFeign.closeOmstruckOrder(orderId);
        return map;
    }

    @ApiOperation(value="根据运单id关闭订单")
    @PostMapping("/getCapacityAndDriverList")
    public Map<String, Object> getCapacityAndDriverList(@RequestBody(required=false) Map<String,Object> mapValue,
                                                        Integer apiId,
                                                        Integer pageNum,
                                                        Integer pageSize,
                                                        String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        Map<String, Object> map = omsFeign.getCapacityAndDriverList(mapValue, apiId, pageNum, pageSize, con);
        return map;
    }

    //查询所有的收货单位
    @GetMapping("/getReceivingUnit")
    public Map<String, Object> getReceivingUnit(){
        return omsFeign.getReceivingUnit();
    }


    //查询所有的发货单位（供应商）
    @GetMapping("/getSupplier")
    public Map<String, Object> getSupplier(){
        return omsFeign.getSupplier();
    }

    @ApiOperation(value = "关闭订单")
    @PostMapping("/CloseOrder")
    public  Map<String,Object> CloseOrder(@RequestBody(required = false)Map<String,Object> map){
        return  omsFeign.CloseOrder(map);
    }
}
