package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiOperation;
import io.swagger.models.auth.In;
import oracle.jdbc.proxy.annotation.Post;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * @ author    :TXF
 * @ time      :2021/10/28 13:28
 */

@FeignClient(value = "DAL-OMS-API-DEV", url = "${openfeign.OMSFeign.url}")
public interface OmsFeign {

     /*
    OmstruckOrderController
     */

    @PostMapping("api/v1/oms/omstruckorders/getAllTruckOrder")
    public Map<String, Object> getAllTruckOrder(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                          @RequestParam("orderStatus") Integer orderStatus,
                                          @RequestParam("planId") Integer planId,
                                          @RequestParam("orderType") Integer orderType,
                                          @RequestParam("fuelOrder") Integer fuelOrder,
                                          @RequestParam("con")String con);

    @PostMapping("api/v1/oms/omstruckorders/getAllTruckOrderReturnListMap")
    public Map<String, Object> getAllTruckOrderReturnListMap(
            @RequestParam("orderStatus") Integer orderStatus,
            @RequestParam("planId") Integer planId,
            @RequestParam("orderType") Integer orderType);

    @PostMapping("api/v1/oms/omstruckorders/getAllCapacity")
    public Map<String, Object> getAllCapacity(@RequestBody(required=false) Map<String,Object> mapValue,
                                        @RequestParam("apiId") Integer apiId,
                                        @RequestParam("pageNum") Integer pageNum,
                                        @RequestParam("pageSize") Integer pageSize,
                                        @RequestParam("carrierId") Integer carrierId);

    @PostMapping("api/v1/oms/omstruckorders/addPurOrder")
    public Map<String, Object> addPurOrder(@RequestBody(required=false) Map<String,Object> mapValue);

    @PostMapping("api/v1/oms/omstruckorders/updateOrder")
    public Map<String, Object> updateOrder(@RequestBody Map<String, Object> map);

    @PostMapping("api/v1/oms/omstruckorders/dispatchOrder")
    public Map<String, Object> dispatchOrder(@RequestBody(required = false) Map<String, Object> map);

    @PostMapping("api/v1/oms/omstruckorders/deleteOrder")
    public Map<String, Object> deleteOrder(@RequestBody(required = false) Map<String, Object> map,
                                     @RequestParam("planId") Integer planId);

    @PostMapping("api/v1/oms/omstruckorders/driverReceiveOrRefuse")
    public Map<String, Object> driverReceiveOrRefuse(@RequestBody(required = false) Map<String, Object> map);

    @PostMapping("api/v1/oms/omstruckorders/getReceiveRefuseOrder/{orderReceiveStatus}")
    public Map<String, Object> getReceiveRefuseOrder(@RequestBody(required=false) Map<String,Object> mapValue,
                                               @RequestParam("apiId") Integer apiId,
                                               @RequestParam("pageNum") Integer pageNum,
                                               @RequestParam("pageSize") Integer pageSize,
                                               @PathVariable("orderReceiveStatus") Integer orderReceiveStatus,
                                               @RequestParam("orderType") Integer orderType,
                                               @RequestParam("orderStatus") Integer orderStatus,
                                                     @RequestParam("con")String con);

    @PostMapping("api/v1/oms/omstruckorders/sendMesToDriver")
    public Map<String, Object> sendMesToDriver(@RequestParam("capacityNumber") String capacityNumber,
                                         @RequestParam("orderStatus") Integer orderStatus);


    @PostMapping("api/v1/oms/omstruckorders/getRefuseOrderByCapacityNum")
    public Map<String, Object> sendMesToDriver(@RequestParam("capacityNumber") String capacityNumber);


    @PostMapping("api/v1/oms/omstruckorders/getOrderMesByOrderNum/{orderId}")
    public Map<String, Object> getOrderMesByOrderNum(@PathVariable("orderId") Integer orderId);

    @PostMapping("api/v1/oms/omstruckorders/selectPlaceAndTime/{orderId}")
    public Map<String, Object> selectPlaceAndTime(@PathVariable("orderId") Integer orderId);

    @PostMapping("api/v1/oms/omstruckorders/selectOrderByOrderId/{orderId}")
    public Map<String, Object> selectOrderByOrderId(@PathVariable("orderId") Integer orderId);

    @PostMapping("api/v1/oms/omstruckorders/getTransportDispatch")
    public Map<String, Object> getTransportDispatch(@RequestBody(required=false) Map<String,Object> mapValue,
                                              @RequestParam("apiId") Integer apiId,
                                              @RequestParam("pageNum") Integer pageNum,
                                              @RequestParam("pageSize") Integer pageSize,
                                              @RequestParam("orderType") Integer orderType,
                                              @RequestParam("orderStatus") Integer orderStatus,
                                              @RequestParam("fuelOrder") Integer fuelOrder,
                                              @RequestParam("con")      String con);
    /**
     * 展示承运商接收销售公司已接受的销售订单
     * @param carrierId
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "api/v1/oms/omstruckorders/getSaleOrderForCarrierList/{carrierId}",method = RequestMethod.POST)
    Map<String,Object> getSaleOrderForCarrierList(@RequestBody(required = false)Map<String,Object> map,
                                                  @PathVariable("carrierId") Integer carrierId,
                                                  @RequestParam Integer apiId,
                                                  @RequestParam Integer pageNum,
                                                  @RequestParam Integer pageSize,
                                                  @RequestParam String con
                                                  );


    /**
     * 销售物流司机接收新的订单
     */
    @PostMapping(value = "api/v1/oms/omstruckorders/getDriverInfoForSale")
    Map<String,Object> getDriverInfoForSale(@RequestBody(required=false) Map<String,Object> mapValue,
                                            @RequestParam("apiId")      Integer apiId,
                                            @RequestParam("pageNum")    Integer pageNum,
                                            @RequestParam("pageSize")   Integer pageSize,

                                            @RequestParam("orderType")  Integer orderType,
                                            @RequestParam("orderStatus")Integer orderStatus,
                                            @RequestParam("con")        String con,
                                            @RequestParam("carrierId")  Integer carrierId
    );

    /**
     * 销售司机派单
     */

    @PostMapping("api/v1/oms/omstruckorders/dispatchOrderForSale")
    Map<String, Object> dispatchOrderForSale(@RequestBody(required = false) Map<String, Object> map);





    /**
     * 查询所有已经接收的焦炭发运日计划
     * @param carrierId
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "api/v1/oms/omstruckorders/getCokeDayPlanAndRecivedList/{carrierId}",method = RequestMethod.POST)
    Map<String,Object> getCokeDayPlanAndRecivedList(@RequestBody(required = false)Map<String,Object> map,
                                                    @PathVariable("carrierId") Integer carrierId,
                                                    @RequestParam Integer apiId,
                                                    @RequestParam Integer pageNum,
                                                    @RequestParam Integer pageSize);
    /**
     *查询所有已经接收的水渣发运日计划
     * @param
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "api/v1/oms/omstruckorders/getWaterSlagDayPlanAndRecivedList/{carrierId}")
    Map<String,Object> getWaterSlagDayPlanAndRecivedList(@RequestBody(required = false)Map<String,Object> map,
                                                         @PathVariable("carrierId") Integer carrierId,
                                                         @RequestParam Integer apiId,
                                                         @RequestParam Integer pageNum,
                                                         @RequestParam Integer pageSize);
    //查询空闲运力信息
    @PostMapping(value = "api/v1/oms/omstruckorders/getCapacityForLeisure/{carrierId}")
    Map<String,Object> getCapacityForLeisure(@RequestBody(required = false) Map<String,Object> mapValue,
                                             @RequestParam("apiId") Integer apiId,
                                             @RequestParam("pageNum") Integer pageNum,
                                             @RequestParam("pageSize") Integer pageSize,
                                             @PathVariable("carrierId")Integer carrierId);

    //通过物资id查询批次表匹配最新的批次，关联最新的采购订单号
    @PostMapping("api/v1/oms/omstruckorders/selectNewOrderId")
    Map<String, Object> selectNewOrderId(@RequestBody(required=false) Map<String,Object> map);


    @PostMapping(value = "api/v1/oms/omstruckorders/selectAllOrderForSale/{carrierId}")
    Map<String, Object> selectAllOrderForSale(
                                                   @RequestBody(required = false) Map<String,Object> mapValue,
                                                   @PathVariable Integer carrierId,
                                                   @RequestParam("apiId") Integer apiId,
                                                   @RequestParam("pageNum") Integer pageNum,
                                                   @RequestParam("pageSize") Integer pageSize,
                                                   @RequestParam("orderType") Integer orderType,
                                                   @RequestParam("orderStatus") Integer orderStatus,
                                                   @RequestParam("saleOrderMaterialId") Integer saleOrderMaterialId,
                                                   @RequestParam("con") String  con
    );


    //展示已经形成虚拟订单的焦炭发运计划
    @PostMapping(value = "api/v1/oms/omstruckorders/getCokeRailDayPlanForGenOrder/{carrierId}")
   Map<String,Object>  getCokeRailDayPlanForGenOrder(@RequestBody(required = false)Map<String,Object> map,
                                                     @PathVariable("carrierId")  Integer carrierId,
                                                     @RequestParam ("pageNum")   Integer pageNum,
                                                     @RequestParam ("pageSize")  Integer pageSize,
                                                     @RequestParam("apiId")      Integer apiId,
                                                     @RequestParam("dayPlanId")  Integer dayPlanId,
                                                     @RequestParam("orderStatus")Integer orderStatus,
                                                     @RequestParam("orderType") Integer orderType,
                                                     @RequestParam("con")  String con
    );
    @PostMapping(value = "api/v1/oms/omstruckorders/getWaterslagDayPlanForGenOrder/{carrierId}")
    Map<String,Object>  getWaterslagDayPlanForGenOrder(@RequestBody(required = false)Map<String,Object> map,
                                                      @PathVariable("carrierId") Integer carrierId,
                                                      @RequestParam("pageNum") Integer pageNum,
                                                      @RequestParam("pageSize") Integer pageSize,
                                                      @RequestParam("apiId") Integer apiId,
                                                      @RequestParam("dayPlanId") Integer dayPlanId,
                                                      @RequestParam("orderType")Integer orderType,
                                                      @RequestParam("orderStatus") Integer orderStatus,
                                                      @RequestParam("con") String con
    );

    @PostMapping("api/v1/oms/omstruckorders/selectSteelSaleForCarrier/{carrierId}")
    public Map<String,Object> selectSteelSaleForCarrier(@RequestBody(required=false) Map<String,Object> mapValue,
                                                   @RequestParam Integer apiId,
                                                   @RequestParam Integer pageNum,
                                                   @RequestParam Integer pageSize,
                                                   @PathVariable Integer carrierId
    );

    @PostMapping("api/v1/oms/omstruckorders/selectInfoBySaleOrderId/{saleOrderId}")
    public Map<String,Object> selectInfoBySaleOrderId(@RequestBody(required=false) Map<String,Object> mapValue,
                                                 @RequestParam Integer apiId,
                                                 @RequestParam Integer pageNum,
                                                 @RequestParam Integer pageSize,
                                                 @PathVariable Integer saleOrderId


    )  ;
    @PostMapping("api/v1/oms/omstruckorders/selectCokeRailPlan/{carrierId}")
     Map<String,Object> selectCokeRailPlan(@RequestBody(required=false) Map<String,Object> mapValue,
                                      @RequestParam Integer apiId,
                                      @RequestParam Integer pageNum,
                                      @RequestParam Integer pageSize,
                                       @PathVariable Integer carrierId,
                                      @RequestParam  Integer orderType

    );
    @PostMapping("api/v1/oms/omstruckorders/selectInfoByDayPlanId/{dayPlanId}")
     Map<String,Object> selectInfoByDayPlanId(@RequestBody(required=false) Map<String,Object> mapValue,
                                              @RequestParam Integer apiId,
                                              @RequestParam Integer pageNum,
                                              @RequestParam Integer pageSize,
                                               @PathVariable  Integer dayPlanId,
                                               @RequestParam Integer orderType


    );

    @ApiOperation(value="车牌号下拉")
    @GetMapping(value = "api/v1/oms/omstruckorders/getDriverCapacity")
    Map<String, Object> getDriverCapacity();

    @ApiOperation(value="派单信息")
    @PostMapping(value = "api/v1/oms/omstruckorders/getTruckNoDispatchMap")
    Map<String, Object> getTruckNoDispatchMap(@RequestParam Integer dispatchId);

    @ApiOperation(value="承运商分派运输订单给司机")
    @PostMapping(value = "api/v1/oms/omstruckorders/addAppTruckOrder")
    Map<String, Object> addAppTruckOrder(@RequestParam Integer dispatchId,
                                         @RequestParam Integer orderType,
                                         @RequestParam String capacityNumber,
                                         @RequestParam Integer carrierId);

    @ApiOperation(value="根据运单id关闭订单")
    @PostMapping(value = "api/v1/oms/omstruckorders/closeOmstruckOrder")
    Map<String, Object> closeOmstruckOrder(@RequestParam Integer orderId);

    @ApiOperation(value="根据运单id关闭订单")
    @PostMapping(value = "api/v1/oms/omstruckorders/getCapacityAndDriverList")
    Map<String, Object> getCapacityAndDriverList(@RequestBody(required=false) Map<String,Object> mapValue,
                                                 @RequestParam Integer apiId,
                                                 @RequestParam Integer pageNum,
                                                 @RequestParam Integer pageSize,
                                                 @RequestParam String con);

    @GetMapping("api/v1/oms/omstruckorders/getReceivingUnit")
    public Map<String, Object> getReceivingUnit();

    //查询所有的发货单位
    @GetMapping("api/v1/oms/omstruckorders/getSupplier")
    public Map<String, Object> getSupplier();

    @PostMapping("api/v1/oms/omstruckorders/CloseOrder")
    Map<String,Object> CloseOrder(@RequestBody(required = false)Map<String,Object> map);
}

