package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @ author    :TXF
 * @ time      :2021/9/28 9:30
 */

@FeignClient(name = "dil-tms-truck-dev", url = "${openfeign.TmsTruckFeign.url}")
public interface TmsTruckFeign {

    /*
    TmstruckLoadResultController
     */
    @PostMapping("api/v1/truckTms/tmstruckloadresults/addLoadResultForConverted")
    Map<String,Object> addLoadResultForConverted(@RequestBody(required=false) Map<String,Object> map);


    @PostMapping("api/v1/truckTms/tmstruckloadresults/getSaleOrderOnQueue")
    public Map<String, Object> getSaleOrderOnQueue(@RequestBody(required=false) Map<String,Object> mapValue,
                                                   @RequestParam("apiId") Integer apiId,
                                                   @RequestParam("pageNum") Integer pageNum,
                                                   @RequestParam("pageSize") Integer pageSize,
                                                   @RequestParam("con") String con);

    @ApiOperation(value="查询订单下的物资")
    @GetMapping("api/v1/truckTms/dropDown/getOrderMaterial/{orderId}")
    public Map<String, Object> getOrderMaterial(@PathVariable("orderId") Integer orderId);

    @ApiOperation(value="查询仓库下所有月台")
    @GetMapping("api/v1/truckTms/dropDown/getPlatformIdByWarehouse/{warehouseId}")
    public Map<String, Object> getPlatformIdByWarehouse(@PathVariable("warehouseId") Integer warehouseId);

    @ApiOperation(value="修改装车点和装车顺序：销售钢材专用 ")
    @PostMapping("api/v1/truckTms/tmstruckloadresults/updateLoadingIdAndLoadSq")
    public Map<String, Object> updateLoadingIdAndLoadSq(@RequestBody(required=false) Map<String, Object> map);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/getAllLoadResult")
    public Map<String, Object> getAllLoadResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                          @RequestParam("status") Integer status ,
                                          @RequestParam("orderType") Integer orderType,
                                          @RequestParam("con") String con);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/selectLoadResultForConverted")
    public Map<String,Object> selectLoadResultForConverted(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/getLoadResultByResultId/{resultId}")
    public Map<String,Object> getLoadResultByResultId(@PathVariable("resultId") Integer resultId);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/addUnLoadResultForconverted")
    public Map<String,Object> addUnLoadResultForconverted(@RequestBody(required = false) Map<String,Object> map);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/addCGLoadResult")
    public Map<String, Object> addCGLoadResult(@RequestBody(required=false) Map<String,Object> mapValue);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/addSaleLoadResult")
    public Map<String, Object> addSaleLoadResult(@RequestBody(required=false) Map<String, Object> map);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/addSale2LoadResult")
    public Map<String, Object> addSale2LoadResult(@RequestBody(required=false) Map<String, Object> map);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/updateLoadResult")
    public Map<String, Object> updateLoadResult(@RequestBody(required=false) Map<String,Object> mapValue);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/getLoadResultById/{resultId}")
    public Map<String, Object> getLoadResultById(@PathVariable("resultId") Integer resultId);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/deleteLoadResult/{resultId}")
    public Map<String, Object> deleteLoadResult(@PathVariable("resultId")Integer resultId);
    /*
        TmstruckEnfactoryResultController
     */

    @ApiOperation(value="查询所有的进厂实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(99)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("api/v1/truckTms/tmstruckenfactoryresults/getAllEnFactoryResult")
    public Map<String, Object> getAllEnFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                               @RequestParam("apiId") Integer apiId,
                                               @RequestParam("pageNum") Integer pageNum,
                                               @RequestParam("pageSize") Integer pageSize,
                                               @RequestParam("orderType")Integer orderType,
                                               @RequestParam("con")      String con
    );
    @GetMapping("api/v1/truckTms/tmstruckenfactoryresults/getMaterial")
    public Map<String , Object> getMaterial(@RequestParam("orderId")  Integer orderId);

    @ApiOperation(value="通过采集系统传来的数据新增进厂作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("api/v1/truckTms/tmstruckenfactoryresults/addEnFactoryResult")
    public Map<String, Object> addEnFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue);


    @ApiOperation(value="PDA扫描更新进厂作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("api/v1/truckTms/tmstruckenfactoryresults/enFactoryResultByPDA")
    public Map<String, Object> enFactoryResultByPDA(@RequestBody(required=false) Map<String,Object> mapValue);


    /*
        TmstruckWeightResultController
     */

    @PostMapping("api/v1/truckTms/tmstruckweightresults/getAllJiMaoResult")
    public Map<String, Object> getAllJiMaoResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                           @RequestParam("apiId") Integer apiId,
                                           @RequestParam("pageNum") Integer pageNum,
                                           @RequestParam("pageSize") Integer pageSize,
                                                 @RequestParam("orderType") Integer orderType,
                                                 @RequestParam("con")     String con
                                                 );

    @PostMapping("api/v1/truckTms/tmstruckweightresults/getAllJiPiResult")
    public Map<String, Object> getAllJiPiResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                                @RequestParam("orderType") Integer orderType,
                                                @RequestParam("con") String con);

    @PostMapping("api/v1/truckTms/tmstruckweightresults/addJiMaoResult")
    public Map<String, Object> addJiMaoResult(@RequestBody Map<String, Object> mapValue);

    @PostMapping("api/v1/truckTms/tmstruckweightresults/addJiPiResult")
    public Map<String, Object> addJiPiResult(@RequestBody Map<String, Object> mapValue);


    /*
     TmstruckUnloadResultController
     */

    @PostMapping("api/v1/truckTms/tmstruckunloadresult/getUnloadResult")
    public Map<String, Object> getUnloadResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                         @RequestParam("apiId") Integer apiId,
                                         @RequestParam("pageNum") Integer pageNum,
                                         @RequestParam("pageSize") Integer pageSize,
                                         @RequestParam("orderType") Integer orderType,
                                         @RequestParam("con")      String con
    );

    @PostMapping("api/v1/truckTms/tmstruckunloadresult/addUnloadResult")
    public Map<String, Object> addUnloadResult(@RequestBody Map<String, Object> mapValue);

    @PostMapping("api/v1/truckTms/tmstruckunloadresult/updateUnloadResult")
    public Map<String, Object> updateUnloadResult(@RequestBody Map<String, Object> mapValue);

    /*
    TmstruckReceiptResultController
     */


    @PostMapping("api/v1/truckTms/tmstruckreceiptresults/getReceiveResult")
    public Map<String, Object> getReceiveResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                          @RequestParam("orderType") Integer orderType,
                                          @RequestParam("con")  String con);

    /*
    TmstruckLeaveFactoryResultController
     */


    @PostMapping("api/v1/truckTms/tmstruckleavefactoryresults/getLeaveFactoryResult")
    public Map<String, Object> getLeaveFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                               @RequestParam("apiId") Integer apiId,
                                               @RequestParam("pageNum") Integer pageNum,
                                               @RequestParam("pageSize") Integer pageSize,
                                               @RequestParam("orderType") Integer orderType,
                                               @RequestParam("con") String con
    );

    @PostMapping("api/v1/truckTms/tmstruckleavefactoryresults/addLeaveFactoryResult")
    public Map<String, Object> addLeaveFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue);


    /*
    TmstruckMeasureCommissionController
     */

    @PostMapping("api/v1/truckTms/tmstruckmeasurecommissions/getAllMeasureCommission/{type}")
    public Map<String, Object> getAllMeasureCommission(@PathVariable("type") Integer type);


    /*
    TmstruckQualityResultController
     */
    @PostMapping("api/v1/truckTms/tmstruckqualityresults/getQualityResult")
    public Map<String, Object> getQualityResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                          @RequestParam("con")String con);


    @PostMapping("api/v1/truckTms/tmstruckqualityresults/getQualityResultById/{resultId}")
    public Map<String, Object> getQualityResultById(@PathVariable("resultId") Integer resultId);


    @PostMapping("api/v1/truckTms/tmstruckqualityresults/updateQualityResult")
    public Map<String, Object> updateQualityResult(@RequestBody(required=false) Map<String,Object> mapValue);

    @PostMapping("api/v1/truckTms/tmstruckqualityresults/selectQualityResultForConverted")
    Map<String,Object> selectQualityResultForConverted(@RequestBody(required=false) Map<String,Object> mapValue,
                                                       @RequestParam("apiId")    Integer apiId,
                                                       @RequestParam("pageNum")  Integer pageNum,
                                                       @RequestParam("pageSize") Integer pageSize);
    /**
     * TmstruckTotalResult
     */
    @PostMapping("api/v1/truckTms/tmstrucktotalresults/selectCountList")
    Map<String,Object> selectCountList(@RequestBody(required=false) Map<String,Object> mapValue,
                                                       @RequestParam("apiId")    Integer apiId,
                                                       @RequestParam("pageNum")  Integer pageNum,
                                                       @RequestParam("pageSize") Integer pageSize);

    /**
     * 下拉框
     */
    @GetMapping("api/v1/truckTms/dropDown/getDilBatch")
    Map<String, Object> getDilBatch();

    @GetMapping("api/v1/truckTms/dropDown/getCarrier")
    Map<String, Object> getCarrier();

    @GetMapping("api/v1/truckTms/dropDown/getLine")
    Map<String, Object> getLine();

    @GetMapping("api/v1/truckTms/dropDown/getWarehouse")
    Map<String, Object> getWarehouse();

    @GetMapping("api/v1/truckTms/dropDown/getGatepost")
    Map<String, Object> getGatepost();

    @GetMapping("api/v1/truckTms/dropDown/getAPO")
    Map<String, Object> getAPO();

    @GetMapping("api/v1/truckTms/dropDown/getFuCapacityId")
    Map<String, Object> getFuCapacityId();

    @GetMapping("api/v1/truckTms/dropDown/getPort")
    Map<String, Object> getPort();

    @GetMapping("api/v1/truckTms/dropDown/getFuMaterial/{type}")
    Map<String, Object> getFuMaterial(@PathVariable("type")Integer type);

    @GetMapping("api/v1/truckTms/dropDown/getUnloadPoint/{type}")
    Map<String, Object> getUnloadPoint(@PathVariable("type") Integer type);
    /**
     * 包月总实绩
     */
    @PostMapping("api/v1/truckTms/tmstrucktotalresults/getTmstruckMonthResult")
    Map<String,Object> getTmstruckMonthResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                       @RequestParam("apiId")    Integer apiId,
                                       @RequestParam("pageNum")  Integer pageNum,
                                       @RequestParam("pageSize") Integer pageSize);
    /**
     *通过运输订单判断下一步是否需要计量,更新汽车衡到计量实绩中
     */
    @PostMapping("api/v1/truckTms/tmstruckweightresults/{orderId}")
    Map<String,Object> isNextNeedJl(@PathVariable("orderId") Integer orderId);


    /**
     *查询短信实绩
     */
    @PostMapping("api/v1/truckTms/tmstrucksmsrusults/getSmsResult")
    Map<String,Object> getSmsResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                    @RequestParam("apiId") Integer apiId,
                                    @RequestParam("pageNum") Integer pageNum,
                                    @RequestParam("pageSize") Integer pageSize,
                                    @RequestParam("con") String con);

    @ApiOperation(value="APP查询进厂实绩")
    @PostMapping("api/v1/truckTms/tmstruckenfactoryresults/getEnfactoryResultList")
    Map<String, Object> getEnfactoryResultList();

    @ApiOperation(value="APP通过运输订单id查询进厂实绩")
    @PostMapping("api/v1/truckTms/tmstruckenfactoryresults/getEnfactoryMessageByOrderId")
    Map<String, Object> getEnfactoryMessageByOrderId(@RequestParam String orderNumber);
}


